aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndreas Schneider <asn@cryptomilk.org>2018-08-06 15:21:59 +0200
committerAndreas Schneider <asn@cryptomilk.org>2018-08-06 15:23:43 +0200
commita86d1d335bd5a9b6f69c30294ca7672f2b2c727c (patch)
tree117d70a9effdf98f2bbff66afc46991e8c3dbf6d
parent18dd90230739b3d2ac486f8dbbecde60cac83dc0 (diff)
downloadlibssh-a86d1d335bd5a9b6f69c30294ca7672f2b2c727c.tar.gz
libssh-a86d1d335bd5a9b6f69c30294ca7672f2b2c727c.tar.xz
libssh-a86d1d335bd5a9b6f69c30294ca7672f2b2c727c.zip
torture: Increase wait time for sshd startup
It is much slower when started with valgrind. Signed-off-by: Andreas Schneider <asn@cryptomilk.org>
-rw-r--r--tests/torture.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/tests/torture.c b/tests/torture.c
index 3640f78c..141cfc15 100644
--- a/tests/torture.c
+++ b/tests/torture.c
@@ -220,7 +220,8 @@ int torture_terminate_process(const char *pidfile)
/* Make sure the daemon goes away! */
kill(pid, SIGTERM);
- usleep(10000);
+ /* 10 ms */
+ usleep(10 * 000);
rc = kill(pid, 0);
if (rc != 0) {
@@ -725,8 +726,8 @@ void torture_setup_sshd_server(void **state)
rc = system(sshd_start_cmd);
assert_return_code(rc, errno);
- /* Give the process 100ms time to initialize and start */
- usleep(100 * 1000);
+ /* Give the process 500ms time to initialize and start */
+ usleep(500 * 1000);
setenv("SOCKET_WRAPPER_DEFAULT_IFACE", "21", 1);
unsetenv("PAM_WRAPPER");